/*
 * Copyright (c) 2005-2007 Substance SwingX Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of Substance Kirill Grouchnikov nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package org.jvnet.substance.swingx;

import java.awt.Graphics2D;

import javax.swing.JComponent;
import javax.swing.JSlider;
import javax.swing.plaf.ComponentUI;

import org.jdesktop.swingx.JXStatusBar;
import org.jdesktop.swingx.plaf.basic.BasicStatusBarUI;
import org.jvnet.lafwidget.layout.TransitionLayout;
import org.jvnet.substance.SubstanceFillBackgroundDelegate;
import org.jvnet.substance.SubstanceLookAndFeel;
import org.jvnet.substance.color.ColorScheme;
import org.jvnet.substance.theme.SubstanceTheme;
import org.jvnet.substance.utils.SubstanceCoreUtilities;

public class SubstanceStatusBarUI extends BasicStatusBarUI {
	/**
	 * Background delegate.
	 */
	private SubstanceFillBackgroundDelegate bgDelegate;

	public static ComponentUI createUI(JComponent c) {
		return new SubstanceStatusBarUI();
	}

	public SubstanceStatusBarUI() {
		super();
		this.bgDelegate = new SubstanceFillBackgroundDelegate();
	}

	@Override
	protected void paintBackground(Graphics2D g, JXStatusBar bar) {
		// SubstanceTheme theme = SubstanceLookAndFeel.getTheme()
		// .getDefaultTitlePaneTheme();
		// SubstanceTitlePainter titlePainter = SubstanceCoreUtilities
		// .getTitlePainter(SwingUtilities.getRootPane(bar));
		//
		// Graphics2D graphics = (Graphics2D) g.create();
		// titlePainter.paintTitleBackground(graphics, bar, bar.getWidth(), bar
		// .getHeight() + 1, 0, bar.getWidth(), theme, false);
		//
		// if (SubstanceCoreUtilities.toDrawWatermark(bar)) {
		// // paint the watermark over the title pane
		// SubstanceLookAndFeel.getCurrentWatermark().drawWatermarkImage(
		// graphics, bar, 0, 0, bar.getWidth(), bar.getHeight());
		// }
		if (TransitionLayout.isOpaque(bar)) {
			this.bgDelegate.update(g, bar);
		}
	}

	@Override
	protected void paintSeparator(Graphics2D g, JXStatusBar bar, int x, int y,
			int w, int h) {
		g.translate(x, y);
		SubstanceTheme theme = SubstanceLookAndFeel.getTheme();
		boolean isDark = SubstanceCoreUtilities.isThemeDark(theme
				.getActiveTheme());
		ColorScheme colorScheme = isDark ? theme.getActiveTheme()
				.getColorScheme() : theme.getDefaultTheme().getColorScheme();

		SubstanceCoreUtilities.paintSeparator(g, colorScheme, isDark, w, h,
				JSlider.VERTICAL);
		g.translate(-x, -y);
	}
//
//	/*
//	 * (non-Javadoc)
//	 * 
//	 * @see javax.swing.plaf.ComponentUI#update(java.awt.Graphics,
//	 *      javax.swing.JComponent)
//	 */
//	@Override
//	public void update(Graphics g, JComponent c) {
//		super.update(g, c);
//		GhostPaintingUtils.paintGhostImages(c, g);
//	}
}
