/*
 * Copyright (c) 2005-2007 Substance SwingX Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of Substance Kirill Grouchnikov nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package org.jvnet.substance.swingx;

import java.awt.Color;

import javax.swing.SwingConstants;
import javax.swing.plaf.ColorUIResource;
import javax.swing.plaf.IconUIResource;

import org.jdesktop.swingx.*;
import org.jdesktop.swingx.calendar.JXMonthView;
import org.jvnet.lafplugin.LafComponentPlugin;
import org.jvnet.substance.SubstanceImageCreator;
import org.jvnet.substance.theme.SubstanceTheme;
import org.jvnet.substance.utils.SubstanceColorUtilities;
import org.jvnet.substance.utils.SubstanceSizeUtils;

public class SubstanceSwingxPlugin implements LafComponentPlugin {

	public SubstanceSwingxPlugin() {
	}

	public Object[] getDefaults(Object theme) {
		SubstanceTheme sTheme = (SubstanceTheme) theme;
		final Color foregroundColor = new ColorUIResource(
				SubstanceColorUtilities.getForegroundColor(sTheme));
		Color backgroundColor = new ColorUIResource(SubstanceColorUtilities
				.getBackgroundColor(sTheme));
		Color backgroundLightColor = new ColorUIResource(backgroundColor
				.brighter());
		Color disabledForegroundColor = new ColorUIResource(
				SubstanceColorUtilities.getDisabledForegroundColor(sTheme));
		Color disabledBackgroundColor = new ColorUIResource(
				SubstanceColorUtilities.getInterpolatedColor(backgroundColor,
						backgroundLightColor, 0.5));
		Color lineColor = new ColorUIResource(SubstanceColorUtilities
				.getLineColor(sTheme));
		int lcb = SubstanceColorUtilities
				.getColorBrightness(lineColor.getRGB());
		Color lineBwColor = new ColorUIResource(new Color(lcb, lcb, lcb));
		Color selectionBackgroundColor = new ColorUIResource(
				SubstanceColorUtilities.getSelectionBackgroundColor(sTheme));
		Color selectionForegroundColor = new ColorUIResource(
				SubstanceColorUtilities.getSelectionForegroundColor(sTheme));
		Color selectionCellForegroundColor = new ColorUIResource(
				SubstanceColorUtilities.getForegroundColor(sTheme
						.getHighlightBackgroundTheme()));

		Object[] defaults = new Object[] {

				JXDatePicker.uiClassID,
				"org.jvnet.substance.swingx.SubstanceDatePickerUI",

				JXMonthView.uiClassID,
				"org.jvnet.substance.swingx.SubstanceMonthViewUI",

				JXTaskPaneContainer.uiClassID,
				"org.jvnet.substance.swingx.SubstanceTaskPaneContainerUI",

				JXTaskPane.uiClassID,
				"org.jvnet.substance.swingx.SubstanceTaskPaneUI",

				JXStatusBar.uiClassID,
				"org.jvnet.substance.swingx.SubstanceStatusBarUI",

				"ColumnHeaderRenderer.upIcon",
				new IconUIResource(SubstanceImageCreator.getArrowIcon(
						SubstanceSizeUtils.getArrowIconWidth(),
						SubstanceSizeUtils.getArrowIconHeight(),
						SubstanceSizeUtils.getArrowStrokeWidth(),
						SwingConstants.NORTH, sTheme)),

				"ColumnHeaderRenderer.downIcon",
				new IconUIResource(SubstanceImageCreator.getArrowIcon(
						SubstanceSizeUtils.getArrowIconWidth(),
						SubstanceSizeUtils.getArrowIconHeight(),
						SubstanceSizeUtils.getArrowStrokeWidth(),
						SwingConstants.SOUTH, sTheme)),

				"JXDatePicker.arrowDown.image",
				new IconUIResource(SubstanceImageCreator.getArrowIcon(
						SubstanceSizeUtils.getArrowIconWidth(),
						SubstanceSizeUtils.getArrowIconHeight(),
						SubstanceSizeUtils.getArrowStrokeWidth(),
						SwingConstants.SOUTH, sTheme)),

				"JXMonthView.background", backgroundColor,

				"JXMonthView.foreground", foregroundColor,

				"JXMonthView.monthStringBackground", backgroundColor,

				"JXMonthView.monthStringForeground", foregroundColor,

				"JXMonthView.daysOfTheWeekForeground", foregroundColor,

				"JXMonthView.weekOfTheYearForeground", foregroundColor,

				"JXMonthView.unselectableDayForeground",
				new ColorUIResource(Color.RED),

				"JXMonthView.selectedBackground", selectionBackgroundColor,

				"JXMonthView.selectedForeground", selectionForegroundColor,

				"JXMonthView.flaggedDayForeground",
				new ColorUIResource(Color.RED),

				"JXMonthView.leadingDayForeground", disabledForegroundColor,

				"JXMonthView.trailingDayForeground", disabledForegroundColor,

				"TaskPane.titleForeground", foregroundColor,

				"TaskPane.titleOver", foregroundColor,

				"TaskPane.specialTitleForeground", foregroundColor,

				"TaskPane.specialTitleOver", foregroundColor,

				"TaskPaneContainer.background", backgroundColor, };

		return defaults;
	}

	public void initialize() {
	}

	public void uninitialize() {
	}
}
