/*
 * Copyright (c) 2005-2007 Substance SwingX Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of Substance Kirill Grouchnikov nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package org.jvnet.substance.swingx;

import java.awt.*;
import java.awt.event.MouseEvent;

import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.MouseInputAdapter;
import javax.swing.event.MouseInputListener;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.basic.BasicGraphicsUtils;

import org.jdesktop.swingx.JXTaskPane;
import org.jdesktop.swingx.icon.EmptyIcon;
import org.jdesktop.swingx.plaf.basic.BasicTaskPaneUI;
import org.jvnet.lafwidget.layout.TransitionLayout;
import org.jvnet.lafwidget.utils.FadeTracker;
import org.jvnet.lafwidget.utils.FadeTracker.FadeKind;
import org.jvnet.substance.*;
import org.jvnet.substance.theme.SubstanceTheme;
import org.jvnet.substance.utils.*;

public class SubstanceTaskPaneUI extends BasicTaskPaneUI {
	/**
	 * Background delegate.
	 */
	private SubstanceFillBackgroundDelegate bgDelegate;

	/**
	 * Delegate for painting the background.
	 */
	private SubstanceGradientBackgroundDelegate headerGradientDelegate;

	protected MouseInputListener substanceMouseInputListener;

//	private static int CONTROL_HEIGHT = 22;

	static {
		TITLE_HEIGHT = 27;
	}

	public static ComponentUI createUI(JComponent c) {
		return new SubstanceTaskPaneUI();
	}

	public SubstanceTaskPaneUI() {
		super();
		this.bgDelegate = new SubstanceFillBackgroundDelegate();
		this.headerGradientDelegate = new SubstanceGradientBackgroundDelegate();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesktop.swingx.plaf.basic.BasicTaskPaneUI#installListeners()
	 */
	@Override
	protected void installListeners() {
		super.installListeners();

		this.substanceMouseInputListener = new MouseInputAdapter() {
			boolean wasInBorder = false;

			@Override
			public void mouseEntered(MouseEvent e) {
				boolean isInBorder = isInBorder(e);
				if (isInBorder) {
					FadeTracker.getInstance().trackFadeIn(FadeKind.ROLLOVER,
							group, false, null);
				}
				wasInBorder = isInBorder;
			}

			@Override
			public void mouseExited(MouseEvent e) {
				boolean isInBorder = isInBorder(e);
				if (wasInBorder) {
					FadeTracker.getInstance().trackFadeOut(FadeKind.ROLLOVER,
							group, false, null);
				}
				wasInBorder = isInBorder;
			}

			@Override
			public void mouseMoved(MouseEvent e) {
				boolean isInBorder = isInBorder(e);
				if (isInBorder != wasInBorder) {
					FadeTracker.getInstance().trackFade(group,
							FadeKind.ROLLOVER, isInBorder, false);
				}
				wasInBorder = isInBorder;
			}
		};
		this.group.addMouseMotionListener(this.substanceMouseInputListener);
		this.group.addMouseListener(this.substanceMouseInputListener);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesktop.swingx.plaf.basic.BasicTaskPaneUI#uninstallListeners()
	 */
	@Override
	protected void uninstallListeners() {
		this.group.removeMouseListener(this.substanceMouseInputListener);
		this.group.removeMouseMotionListener(this.substanceMouseInputListener);
		this.substanceMouseInputListener = null;

		super.uninstallListeners();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesktop.swingx.plaf.basic.BasicTaskPaneUI#createPaneBorder()
	 */
	protected Border createPaneBorder() {
		return new SubstancePaneBorder();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesktop.swingx.plaf.basic.BasicTaskPaneUI#createContentPaneBorder()
	 */
	protected Border createContentPaneBorder() {
		return new CompoundBorder(new LineBorder(SubstanceCoreUtilities
				.getDefaultTheme(group, true).getColorScheme().getMidColor()),
				new EmptyBorder(1, 2, 2, 2));
		// // return new CompoundBorder(new LiquidContentPaneBorder(new
		// Color(145,
		// // 155, 156)), BorderFactory.createEmptyBorder(10, 10, 10, 10));
	}

	protected class SubstancePaneBorder extends PaneBorder {

		public SubstancePaneBorder() {
			this.borderColor = SubstanceCoreUtilities.getDefaultTheme(group,
					true).getColorScheme().getMidColor();
		}

		/*
		 * (non-Javadoc)
		 * 
		 * @see org.jdesktop.swingx.plaf.basic.BasicTaskPaneUI$PaneBorder#paintTitleBackground(org.jdesktop.swingx.JXTaskPane,
		 *      java.awt.Graphics)
		 */
		protected void paintTitleBackground(JXTaskPane group, Graphics g) {
			boolean isPaintedActive = /* group.isSpecial() || */mouseOver;

			boolean isUnderFade = FadeTracker.getInstance().isTracked(group,
					FadeKind.ROLLOVER);
			SubstanceTheme defaultTheme = SubstanceCoreUtilities
					.getDefaultTheme(group, true);
			SubstanceTheme activeTheme = SubstanceCoreUtilities.getActiveTheme(
					group, true);
			if (!isUnderFade) {
				SubstanceTheme theme = isPaintedActive ? activeTheme
						: defaultTheme;
				headerGradientDelegate.update(g, group, new Rectangle(0, 0,
						group.getWidth(), TITLE_HEIGHT), theme, true);
			} else {
				Graphics2D graphics = (Graphics2D) g.create();
				headerGradientDelegate.update(graphics, group, new Rectangle(0,
						0, group.getWidth(), TITLE_HEIGHT), defaultTheme, true);
				graphics.setComposite(TransitionLayout.getAlphaComposite(group,
						FadeTracker.getInstance().getFade10(group,
								FadeKind.ROLLOVER) / 10.0f));
				headerGradientDelegate.update(graphics, group, new Rectangle(0,
						0, group.getWidth(), TITLE_HEIGHT), activeTheme, true);
				graphics.dispose();
			}
		}

		/*
		 * (non-Javadoc)
		 * 
		 * @see org.jdesktop.swingx.plaf.basic.BasicTaskPaneUI$PaneBorder#paintExpandedControls(org.jdesktop.swingx.JXTaskPane,
		 *      java.awt.Graphics, int, int, int, int)
		 */
		protected void paintExpandedControls(JXTaskPane group, Graphics g,
				int x, int y, int width, int height) {

			int type = group.isExpanded() ? SwingConstants.NORTH
					: SwingConstants.SOUTH;

			Icon arrowIcon = SubstanceImageCreator.getDoubleArrowIcon(
					SubstanceSizeUtils.getArrowIconWidth(), SubstanceSizeUtils
							.getArrowIconHeight() + 2, SubstanceSizeUtils
							.getDoubleArrowStrokeWidth(), type,
					SubstanceCoreUtilities.getActiveTheme(group, true));
			arrowIcon.paintIcon(group, g, x + 3, y + 4);
		}

		/*
		 * (non-Javadoc)
		 * 
		 * @see org.jdesktop.swingx.plaf.basic.BasicTaskPaneUI$PaneBorder#isMouseOverBorder()
		 */
		protected boolean isMouseOverBorder() {
			return true;
		}

		/*
		 * (non-Javadoc)
		 * 
		 * @see org.jdesktop.swingx.plaf.basic.BasicTaskPaneUI$PaneBorder#paintFocus(java.awt.Graphics,
		 *      java.awt.Color, int, int, int, int)
		 */
		protected void paintFocus(Graphics g, Color paintColor, int x, int y,
				int width, int height) {
			g.setColor(paintColor);
			BasicGraphicsUtils.drawDashedRect(g, x - 1, y - 1, width + 2,
					height + 2);
		}

		/*
		 * (non-Javadoc)
		 * 
		 * @see org.jdesktop.swingx.plaf.basic.BasicTaskPaneUI$PaneBorder#configureLabel(org.jdesktop.swingx.JXTaskPane)
		 */
		protected void configureLabel(JXTaskPane group) {
			label.applyComponentOrientation(group.getComponentOrientation());
			label.setFont(group.getFont());
			label.setText(group.getTitle());
			label.setIcon(group.getIcon() == null ? new EmptyIcon() : group
					.getIcon());
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.plaf.ComponentUI#paint(java.awt.Graphics,
	 *      javax.swing.JComponent)
	 */
	@Override
	public void paint(Graphics g, JComponent c) {
		if (TransitionLayout.isOpaque(c)) {
			this.bgDelegate.update(g, c);
		}
		super.paint(g, c);
	}
}
