/*
 * Copyright (c) 2005-2007 Substance Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of Substance Kirill Grouchnikov nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package test;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Component;
import java.util.Calendar;
import java.util.Date;

import javax.swing.DefaultCellEditor;
import javax.swing.ImageIcon;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.ListSelectionModel;
import javax.swing.table.AbstractTableModel;
import javax.swing.table.JTableHeader;
import javax.swing.table.TableCellRenderer;
import javax.swing.table.TableModel;

import org.jdesktop.swingx.JXTable;
import org.jdesktop.swingx.decorator.AlternateRowHighlighter;
import org.jdesktop.swingx.decorator.Highlighter;
import org.jdesktop.swingx.decorator.HighlighterPipeline;
import org.jvnet.lafwidget.utils.FadeTracker;
import org.jvnet.lafwidget.utils.FadeTracker.FadeKind;
import org.jvnet.lafwidget.utils.LafConstants.AnimationKind;
import org.jvnet.substance.SubstanceImageCreator;
import org.jvnet.substance.SubstanceLookAndFeel;
import org.jvnet.substance.theme.SubstanceTheme;
import org.jvnet.substance.theme.ThemeInfo;
import org.jvnet.substance.utils.SubstanceColorUtilities;


public class TablePanel extends JPanel {
	private JXTable table;

	private Object[][] data;

	private Class[] columns;

	private static class MyColorTableRenderer extends JLabel implements
			TableCellRenderer {
		public Component getTableCellRendererComponent(JTable table,
				Object value, boolean isSelected, boolean hasFocus, int row,
				int column) {
			Color color = (Color) value;
			this.setForeground(color);
			this.setBackground(SubstanceColorUtilities.invertColor(color));
			this.setText("row " + row);
			return this;
		}
	}

	private static class MyFloatTableRenderer extends JLabel implements
			TableCellRenderer {
		public Component getTableCellRendererComponent(JTable table,
				Object value, boolean isSelected, boolean hasFocus, int row,
				int column) {
			int c = (10 * row) % 255;
			Color color = new Color(c, c, c);
			this.setForeground(new Color(255 - c, 0, 0));
			this.setBackground(color);
			this.setText(value.toString());
			return this;
		}
	}

	public TablePanel() {
		final int rows = 400;
		final int cols = 10;
		this.data = new Object[rows][cols];
		this.columns = new Class[] { String.class, JComboBox.class,
				Boolean.class, Byte.class, Float.class, Double.class,
				String.class, Date.class, ImageIcon.class, Color.class };

		for (int i = 0; i < rows; i++) {
			this.data[i][0] = "cell " + i + ":" + 0;
			this.data[i][1] = "predef";
			this.data[i][2] = new Boolean(i % 2 == 0);
			this.data[i][3] = new Byte((byte) i);
			this.data[i][4] = new Float((float) i);
			this.data[i][5] = new Double((double) i);
			this.data[i][6] = "cell " + i + ":" + 6;
			Calendar cal = Calendar.getInstance();
			cal.set(2000 + i, 1 + i, 1 + i);
			this.data[i][7] = cal.getTime();
			int count = 0;
			for (ThemeInfo themeInfo : SubstanceLookAndFeel.getAllThemes()
					.values()) {
				if (count++ == i) {
					try {
						this.data[i][8] = SubstanceImageCreator
								.getHexaMarker(6, (SubstanceTheme) Class
										.forName(themeInfo.getClassName())
										.newInstance());
					} catch (Exception exc) {
					}
				}
			}

			int comp = i * 20;
			int red = (comp / 3) % 255;
			int green = (comp / 2) % 255;
			int blue = comp % 255;
			this.data[i][9] = new Color(red, green, blue);
		}

		TableModel dataModel = new AbstractTableModel() {
			@Override
			public Class<?> getColumnClass(int columnIndex) {
				return columns[columnIndex];
			}

			public int getColumnCount() {
				return cols;
			}

			public int getRowCount() {
				return rows;
			}

			public Object getValueAt(int row, int col) {
				return data[row][col];
			}

			@Override
			public String getColumnName(int column) {
				return this.getColumnClass(column).getSimpleName();
			}

			@Override
			public boolean isCellEditable(int rowIndex, int columnIndex) {
				return (rowIndex % 2 == 0);
			}

			@Override
			public void setValueAt(Object value, int row, int col) {
				data[row][col] = value;
				fireTableCellUpdated(row, col);
			}
		};
		this.table = new JXTable(dataModel);
		this.table.setDefaultRenderer(Color.class, new MyColorTableRenderer());
		this.table.setDefaultRenderer(Float.class, new MyFloatTableRenderer());
		final JScrollPane tableScrollpane = new JScrollPane(this.table);
		
		this.table.setColumnControlVisible(true);
		this.table.setHighlighters(new HighlighterPipeline(
		        new Highlighter[]{ AlternateRowHighlighter.classicLinePrinter }));

		JComboBox combo = new JComboBox(new Object[] { "aa", "bb", "cc" });
		combo.setBorder(null);
		this.table.getColumnModel().getColumn(1).setCellEditor(
				new DefaultCellEditor(combo));

		this.table
				.setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
		this.table.setCellSelectionEnabled(true);
		this.table.setColumnSelectionAllowed(true);
		this.table.setShowGrid(true);
		this.table.setDragEnabled(false);

		this.setLayout(new BorderLayout());
		this.add(tableScrollpane, BorderLayout.CENTER);

	}
}