/*
 * Copyright (c) 2005-2007 Substance SwingX Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of Substance Kirill Grouchnikov nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package test;

import java.awt.*;
import java.awt.event.AWTEventListener;
import java.awt.event.MouseEvent;
import java.util.Calendar;

import javax.swing.*;

import org.jdesktop.swingx.*;
import org.jdesktop.swingx.calendar.JXMonthView;

public class TestFrame extends JFrame {

	TestFrame() {
		super("SwingX testing bed");

		Calendar cal = Calendar.getInstance();
		cal.add(Calendar.DAY_OF_MONTH, 4);
		long[] unselDates = new long[3];
		unselDates[0] = cal.getTimeInMillis();
		cal.add(Calendar.DAY_OF_MONTH, 3);
		unselDates[1] = cal.getTimeInMillis();
		cal.add(Calendar.DAY_OF_MONTH, 3);
		unselDates[2] = cal.getTimeInMillis();
		long[] flaggedDates = new long[3];
		cal.add(Calendar.DAY_OF_MONTH, 1);
		flaggedDates[0] = cal.getTimeInMillis();
		cal.add(Calendar.DAY_OF_MONTH, 2);
		flaggedDates[1] = cal.getTimeInMillis();
		cal.add(Calendar.DAY_OF_MONTH, 2);
		flaggedDates[2] = cal.getTimeInMillis();

		JXTaskPaneContainer taskPaneContainer = new JXTaskPaneContainer();

		JXTaskPane taskPane = new JXTaskPane();
		taskPane.setTitle("JXMonthView and JXDatePicker");
		taskPaneContainer.add(taskPane);
		JXMonthView monthView = new JXMonthView();
		monthView.setFlaggedDates(flaggedDates);
		monthView.setUnselectableDates(unselDates);
		monthView.setShowLeadingDates(true);
		monthView.setShowTrailingDates(true);
		// monthView.setFlaggedDates(unselDates);
		taskPane.add(monthView);

		JXDatePicker datePicker = new JXDatePicker();
		datePicker.getMonthView().setUnselectableDates(unselDates);
		taskPane.add(datePicker);

		taskPane = new JXTaskPane();
		taskPane.setTitle("Task Pane 2");
		taskPane.setSpecial(true);
		taskPaneContainer.add(taskPane);
		JXHyperlink link = new JXHyperlink();
		link.setText("My first link");
		taskPane.add(link);

		taskPane = new JXTaskPane();
		taskPane.setTitle("Task Pane 3");
		taskPaneContainer.add(taskPane);
		taskPane.add(new JButton("Push me"));
		taskPane.add(new JTextField("Field 1"));

		this.add(new JScrollPane(taskPaneContainer), BorderLayout.WEST);
		
		JXStatusBar statusBar = new JXStatusBar();
		this.add(statusBar, BorderLayout.SOUTH);
		
		this.add(new TablePanel(), BorderLayout.CENTER);
 
		final JLabel statusLabel = new JLabel("");
		JXStatusBar.Constraint c1 = new JXStatusBar.Constraint();
		c1.setFixedWidth(100);
		statusBar.add(statusLabel, c1);
		Toolkit.getDefaultToolkit().addAWTEventListener(new AWTEventListener() {
			public void eventDispatched(AWTEvent event) {
				if (event instanceof MouseEvent) {
					MouseEvent me = (MouseEvent) event;
					if (me.getID() == MouseEvent.MOUSE_MOVED) {
						Point p = me.getPoint();
						statusLabel.setText(p.x + ":" + p.y);
					}
				}
			}
		}, AWTEvent.MOUSE_MOTION_EVENT_MASK);
		
		this.setSize(800, 600);
		this.setLocationRelativeTo(null);
		this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

		// LAF changing
		JMenu lafMenu = new JMenu("Look & feel");
		JMenu substanceMenus = new JMenu("Substance family");
		substanceMenus.add(LafChanger.getMenuItem(this, "Substance",
				"org.jvnet.substance.SubstanceLookAndFeel"));
		substanceMenus.add(LafChanger.getMenuItem(this, "Substance Default",
				"org.jvnet.substance.SubstanceDefaultLookAndFeel"));
		substanceMenus.addSeparator();
		substanceMenus.add(LafChanger.getMenuItem(this, "Substance Business",
				"org.jvnet.substance.skin.SubstanceBusinessLookAndFeel"));
		substanceMenus.add(LafChanger.getMenuItem(this, "Substance Creme",
				"org.jvnet.substance.skin.SubstanceCremeLookAndFeel"));
		substanceMenus.add(LafChanger.getMenuItem(this, "Substance Moderate",
				"org.jvnet.substance.skin.SubstanceModerateLookAndFeel"));
		substanceMenus
				.add(LafChanger
						.getMenuItem(this, "Substance Office Silver 2007",
								"org.jvnet.substance.skin.SubstanceOfficeSilver2007LookAndFeel"));
		substanceMenus.add(LafChanger.getMenuItem(this, "Substance Sahara",
				"org.jvnet.substance.skin.SubstanceSaharaLookAndFeel"));
		substanceMenus.addSeparator();
		substanceMenus.add(LafChanger.getMenuItem(this,
				"Substance Field of Wheat",
				"org.jvnet.substance.skin.SubstanceFieldOfWheatLookAndFeel"));
		substanceMenus.add(LafChanger.getMenuItem(this,
				"Substance Green Magic",
				"org.jvnet.substance.skin.SubstanceGreenMagicLookAndFeel"));
		substanceMenus.add(LafChanger.getMenuItem(this, "Substance Mango",
				"org.jvnet.substance.skin.SubstanceMangoLookAndFeel"));
		substanceMenus.add(LafChanger.getMenuItem(this,
				"Substance Office Blue 2007",
				"org.jvnet.substance.skin.SubstanceOfficeBlue2007LookAndFeel"));
		substanceMenus.addSeparator();
		substanceMenus.add(LafChanger.getMenuItem(this,
				"Substance Challenger Deep",
				"org.jvnet.substance.skin.SubstanceChallengerDeepLookAndFeel"));
		substanceMenus.add(LafChanger.getMenuItem(this,
				"Substance Emerald Dusk",
				"org.jvnet.substance.skin.SubstanceEmeraldDuskLookAndFeel"));
		substanceMenus.add(LafChanger.getMenuItem(this, "Substance Magma",
				"org.jvnet.substance.skin.SubstanceMagmaLookAndFeel"));
		substanceMenus.add(LafChanger.getMenuItem(this, "Substance Raven",
				"org.jvnet.substance.skin.SubstanceRavenLookAndFeel"));
		lafMenu.add(substanceMenus);
		lafMenu.addSeparator();
		JMenu coreLafMenus = new JMenu("Core LAFs");
		lafMenu.add(coreLafMenus);
		coreLafMenus.add(LafChanger.getMenuItem(this, "Metal",
				"javax.swing.plaf.metal.MetalLookAndFeel"));
		coreLafMenus.add(LafChanger.getMenuItem(this, "Windows",
				"com.sun.java.swing.plaf.windows.WindowsLookAndFeel"));
		coreLafMenus.add(LafChanger.getMenuItem(this, "Windows Classic",
				"com.sun.java.swing.plaf.windows.WindowsClassicLookAndFeel"));
		coreLafMenus.add(LafChanger.getMenuItem(this, "Motif",
				"com.sun.java.swing.plaf.motif.MotifLookAndFeel"));

		JMenu customLafMenus = new JMenu("Custom LAFs");
		lafMenu.add(customLafMenus);
		JMenu jgoodiesMenu = new JMenu("JGoodies family");
		customLafMenus.add(jgoodiesMenu);
		jgoodiesMenu.add(LafChanger.getMenuItem(this, "JGoodies Plastic",
				"com.jgoodies.looks.plastic.PlasticLookAndFeel"));
		jgoodiesMenu.add(LafChanger.getMenuItem(this, "JGoodies PlasticXP",
				"com.jgoodies.looks.plastic.PlasticXPLookAndFeel"));
		jgoodiesMenu.add(LafChanger.getMenuItem(this, "JGoodies Plastic3D",
				"com.jgoodies.looks.plastic.Plastic3DLookAndFeel"));

		JMenu jtattooMenu = new JMenu("JTattoo family");
		customLafMenus.add(jtattooMenu);
		jtattooMenu.add(LafChanger.getMenuItem(this, "JTattoo Acryl",
				"com.jtattoo.plaf.acryl.AcrylLookAndFeel"));
		jtattooMenu.add(LafChanger.getMenuItem(this, "JTattoo Aero",
				"com.jtattoo.plaf.aero.AeroLookAndFeel"));
		jtattooMenu.add(LafChanger.getMenuItem(this, "JTattoo Aluminium",
				"com.jtattoo.plaf.aluminium.AluminiumLookAndFeel"));
		jtattooMenu.add(LafChanger.getMenuItem(this, "JTattoo Bernstein",
				"com.jtattoo.plaf.bernstein.BernsteinLookAndFeel"));
		jtattooMenu.add(LafChanger.getMenuItem(this, "JTattoo Fast",
				"com.jtattoo.plaf.fast.FastLookAndFeel"));
		jtattooMenu.add(LafChanger.getMenuItem(this, "JTattoo HiFi",
				"com.jtattoo.plaf.hifi.HiFiLookAndFeel"));
		jtattooMenu.add(LafChanger.getMenuItem(this, "JTattoo Luna",
				"com.jtattoo.plaf.luna.LunaLookAndFeel"));
		jtattooMenu.add(LafChanger.getMenuItem(this, "JTattoo McWin",
				"com.jtattoo.plaf.mcwin.McWinLookAndFeel"));
		jtattooMenu.add(LafChanger.getMenuItem(this, "JTattoo Mint",
				"com.jtattoo.plaf.mint.MintLookAndFeel"));
		jtattooMenu.add(LafChanger.getMenuItem(this, "JTattoo Smart",
				"com.jtattoo.plaf.smart.SmartLookAndFeel"));

		JMenu syntheticaMenu = new JMenu("Synthetica family");
		customLafMenus.add(syntheticaMenu);
		syntheticaMenu.add(LafChanger.getMenuItem(this, "Synthetica base",
				"de.javasoft.plaf.synthetica.SyntheticaStandardLookAndFeel"));
		syntheticaMenu.add(LafChanger.getMenuItem(this, "Synthetica BlackMoon",
				"de.javasoft.plaf.synthetica.SyntheticaBlackMoonLookAndFeel"));
		syntheticaMenu.add(LafChanger.getMenuItem(this, "Synthetica BlackStar",
				"de.javasoft.plaf.synthetica.SyntheticaBlackStarLookAndFeel"));
		syntheticaMenu.add(LafChanger.getMenuItem(this, "Synthetica BlueIce",
				"de.javasoft.plaf.synthetica.SyntheticaBlueIceLookAndFeel"));
		syntheticaMenu.add(LafChanger.getMenuItem(this, "Synthetica BlueMoon",
				"de.javasoft.plaf.synthetica.SyntheticaBlueMoonLookAndFeel"));
		syntheticaMenu.add(LafChanger.getMenuItem(this, "Synthetica BlueSteel",
				"de.javasoft.plaf.synthetica.SyntheticaBlueSteelLookAndFeel"));
		syntheticaMenu.add(LafChanger.getMenuItem(this,
				"Synthetica GreenDream",
				"de.javasoft.plaf.synthetica.SyntheticaGreenDreamLookAndFeel"));
		syntheticaMenu
				.add(LafChanger
						.getMenuItem(this, "Synthetica OrangeMetallic",
								"de.javasoft.plaf.synthetica.SyntheticaOrangeMetallicLookAndFeel"));
		syntheticaMenu.add(LafChanger.getMenuItem(this,
				"Synthetica SilverMoon",
				"de.javasoft.plaf.synthetica.SyntheticaSilverMoonLookAndFeel"));

		JMenu officeMenu = new JMenu("Office family");
		customLafMenus.add(officeMenu);
		officeMenu.add(LafChanger.getMenuItem(this, "Office 2003",
				"org.fife.plaf.Office2003.Office2003LookAndFeel"));
		officeMenu.add(LafChanger.getMenuItem(this, "Office XP",
				"org.fife.plaf.OfficeXP.OfficeXPLookAndFeel"));
		officeMenu.add(LafChanger.getMenuItem(this, "Visual Studio 2005",
				"org.fife.plaf.VisualStudio2005.VisualStudio2005LookAndFeel"));

		customLafMenus.add(LafChanger.getMenuItem(this, "A03",
				"apprising.api.swing.plaf.a03.A03LookAndFeel"));
		customLafMenus.add(LafChanger.getMenuItem(this, "Alloy",
				"com.incors.plaf.alloy.AlloyLookAndFeel"));
		customLafMenus.add(LafChanger.getMenuItem(this, "FH",
				"com.shfarr.ui.plaf.fh.FhLookAndFeel"));
		customLafMenus.add(LafChanger.getMenuItem(this, "Hippo",
				"se.diod.hippo.plaf.HippoLookAndFeel"));
		customLafMenus.add(LafChanger.getMenuItem(this, "Kuntstoff",
				"com.incors.plaf.kunststoff.KunststoffLookAndFeel"));
		customLafMenus.add(LafChanger.getMenuItem(this, "Liquid",
				"com.birosoft.liquid.LiquidLookAndFeel"));
		customLafMenus.add(LafChanger.getMenuItem(this, "Lipstik",
				"com.lipstikLF.LipstikLookAndFeel"));
		customLafMenus.add(LafChanger.getMenuItem(this, "Metouia",
				"net.sourceforge.mlf.metouia.MetouiaLookAndFeel"));
		customLafMenus.add(LafChanger.getMenuItem(this, "Napkin",
				"net.sourceforge.napkinlaf.NapkinLookAndFeel"));
		customLafMenus.add(LafChanger.getMenuItem(this, "NimROD",
				"com.nilo.plaf.nimrod.NimRODLookAndFeel"));
		customLafMenus.add(LafChanger.getMenuItem(this, "Oyoaha",
				"com.oyoaha.swing.plaf.oyoaha.OyoahaLookAndFeel"));
		customLafMenus.add(LafChanger.getMenuItem(this, "Pagosoft",
				"com.pagosoft.plaf.PgsLookAndFeel"));
		customLafMenus.add(LafChanger.getMenuItem(this, "Simple",
				"com.memoire.slaf.SlafLookAndFeel"));
		customLafMenus.add(LafChanger.getMenuItem(this, "Skin",
				"com.l2fprod.gui.plaf.skin.SkinLookAndFeel"));
		customLafMenus.add(LafChanger.getMenuItem(this, "Smooth Metal",
				"smooth.metal.SmoothLookAndFeel"));
		customLafMenus.add(LafChanger.getMenuItem(this, "Squareness",
				"net.beeger.squareness.SquarenessLookAndFeel"));
		customLafMenus.add(LafChanger.getMenuItem(this, "Tiny",
				"de.muntjak.tinylookandfeel.TinyLookAndFeel"));
		customLafMenus.add(LafChanger.getMenuItem(this, "Tonic",
				"com.digitprop.tonic.TonicLookAndFeel"));
		customLafMenus.add(LafChanger.getMenuItem(this, "Trendy",
				"com.Trendy.swing.plaf.TrendyLookAndFeel"));

		JMenuBar jmb = new JMenuBar();
		jmb.add(lafMenu);
		this.setJMenuBar(jmb);
	}

	public static void main(String[] args) {
		JFrame.setDefaultLookAndFeelDecorated(true);
		try {
			UIManager
					.setLookAndFeel("org.jvnet.substance.SubstanceLookAndFeel");
		} catch (Exception ex) {
			ex.printStackTrace();
		}

		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				new TestFrame().setVisible(true);
			}
		});
	}
}
