/*
 * Copyright (c) 2005-2007 Substance SwingX Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of Substance Kirill Grouchnikov nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package test;

import java.awt.*;
import java.awt.event.*;

import javax.swing.*;
import javax.swing.plaf.metal.MetalLookAndFeel;

import org.jdesktop.swingx.JXStatusBar;
import org.jvnet.substance.skin.SubstanceRavenGraphiteLookAndFeel;

import com.sun.java.swing.plaf.windows.WindowsLookAndFeel;

public class TestStatusBar extends JFrame {
	public TestStatusBar() {
		this.setLayout(new BorderLayout());

		JXStatusBar statusBar = new JXStatusBar();
		this.add(statusBar, BorderLayout.SOUTH);

		final JLabel statusLabel = new JLabel("");
		JXStatusBar.Constraint c1 = new JXStatusBar.Constraint();
		c1.setFixedWidth(100);
		statusBar.add(statusLabel, c1);
		Toolkit.getDefaultToolkit().addAWTEventListener(new AWTEventListener() {
			public void eventDispatched(AWTEvent event) {
				if (event instanceof MouseEvent) {
					MouseEvent me = (MouseEvent) event;
					if (me.getID() == MouseEvent.MOUSE_MOVED) {
						Point p = me.getPoint();
						statusLabel.setText(p.x + ":" + p.y);
					}
				}
			}
		}, AWTEvent.MOUSE_MOTION_EVENT_MASK);

		JPanel controls = new JPanel(new FlowLayout());
		final JButton winLaf = new JButton("Windows LAF");
		final JButton metalLaf = new JButton("Metal LAF");
		metalLaf.setEnabled(false);
		winLaf.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				SwingUtilities.invokeLater(new Runnable() {
					public void run() {
						try {
							winLaf.setEnabled(false);
							metalLaf.setEnabled(true);
							UIManager.setLookAndFeel(new WindowsLookAndFeel());
							SwingUtilities
									.updateComponentTreeUI(TestStatusBar.this);
						} catch (Exception exc) {
							exc.printStackTrace();
						}
					}
				});
			}
		});
		metalLaf.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				SwingUtilities.invokeLater(new Runnable() {
					public void run() {
						try {
							winLaf.setEnabled(true);
							metalLaf.setEnabled(false);
							UIManager.setLookAndFeel(new MetalLookAndFeel());
							SwingUtilities
									.updateComponentTreeUI(TestStatusBar.this);
						} catch (Exception exc) {
							exc.printStackTrace();
						}
					}
				});
			}
		});
		controls.add(winLaf);
		controls.add(metalLaf);
		
		this.add(controls, BorderLayout.CENTER);
		
		this.setSize(400, 300);
		this.setLocationRelativeTo(null);
		this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	}
	 
	public static void main(String[] args) throws Exception {
		UIManager.setLookAndFeel(new SubstanceRavenGraphiteLookAndFeel());
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				new TestStatusBar().setVisible(true);
			}
		});
	}
}
